@@ -2,9 +2,9 @@
 #include "apollota/triangulation_queries.h"
 #include "apollota/rolling_topology.h"
 
-#include "auxiliaries/io_utilities.h"
 #include "auxiliaries/opengl_printer.h"
 #include "auxiliaries/program_options_handler.h"
+#include "auxiliaries/io_utilities.h"
 
 namespace
 {
@@ -12,7 +12,7 @@ namespace
 class SubdividedSphericalTriangulation
 {
 public:
-	SubdividedSphericalTriangulation(const int steps) : center_sphere_(0, 0, 0, 1)
+	explicit SubdividedSphericalTriangulation(const int steps) : center_sphere_(0, 0, 0, 1)
 	{
 		const double t=(1+sqrt(5.0))/2.0;
 
