@@ -1,8 +1,15 @@
 #include "auxiliaries/program_options_handler.h"
 #include "auxiliaries/io_utilities.h"
 
-#include "modescommon/contacts_scoring_utilities.h"
-#include "modescommon/statistics_utilities.h"
+#include "common/contacts_scoring_utilities.h"
+#include "common/statistics_utilities.h"
+
+namespace
+{
+
+typedef common::InteractionName InteractionName;
+
+}
 
 void score_contacts_potentials_stats(const auxiliaries::ProgramOptionsHandler& poh)
 {
@@ -15,7 +22,7 @@ void score_contacts_potentials_stats(const auxiliaries::ProgramOptionsHandler& p
 		return;
 	}
 
-	std::map<InteractionName, ValueStat> map_of_value_stats;
+	std::map<InteractionName, common::ValueStat> map_of_value_stats;
 	while(std::cin.good())
 	{
 		std::string potential_file;
@@ -27,10 +34,10 @@ void score_contacts_potentials_stats(const auxiliaries::ProgramOptionsHandler& p
 		}
 	}
 
-	std::map<InteractionName, NormalDistributionParameters> means_and_sds;
-	for(std::map<InteractionName, ValueStat>::const_iterator it=map_of_value_stats.begin();it!=map_of_value_stats.end();++it)
+	std::map<InteractionName, common::NormalDistributionParameters> means_and_sds;
+	for(std::map<InteractionName, common::ValueStat>::const_iterator it=map_of_value_stats.begin();it!=map_of_value_stats.end();++it)
 	{
-		means_and_sds[it->first]=NormalDistributionParameters(it->second.mean(), it->second.sd());
+		means_and_sds[it->first]=common::NormalDistributionParameters(it->second.mean(), it->second.sd());
 	}
 
 	auxiliaries::IOUtilities().write_map(means_and_sds, std::cout);
